import { Beatmap, BeatmapCompact } from "./beatmap";
import { KudosuHistory, User, UserCompact } from "./user";
import { Leader, MultiplayerScore, PlaylistItem, Room } from "./multiplayer";
import { GameModes } from "./misc";
import { BeatmapUserScore, Score } from "./score";
export { Beatmap, BeatmapCompact };
export { User, UserCompact, KudosuHistory };
export { BeatmapUserScore, Score };
export { Room, Leader, PlaylistItem, MultiplayerScore };
export { GameModes };
export declare class APIError {
    message: string;
    /**
     * @param message The reason why things didn't go as expected
     */
    constructor(message: string);
}
export declare class API {
    client: {
        id: number;
        secret: string;
    };
    token_type: string;
    expires: Date;
    access_token: string;
    refresh_token?: string;
    user?: number;
    scopes: Scope[];
    private constructor();
    static createAsync: (client: {
        id: number;
        secret: string;
    }, user?: {
        code: string;
        redirect_uri: string;
    }) => Promise<API | null>;
    refreshToken(): Promise<boolean>;
    /**
     * @param type Basically the endpoint, what comes in the URL after `api/`
     * @param params The things to specify in the request, such as the beatmap_id when looking for a beatmap
     * @param number_try How many attempts there's been to get the data
     * @returns A Promise with either the API's response or `false` upon failing
     */
    private request;
    /**
     * REQUIRES A USER ASSOCIATED TO THE API OBJECT
     */
    getResourceOwner(gamemode?: GameModes): Promise<User | APIError>;
    getUser(user: {
        id?: number;
        username?: string;
    } | UserCompact, gamemode?: GameModes): Promise<User | APIError>;
    getUsers(ids?: number[]): Promise<UserCompact[] | APIError>;
    getUserScores(limit: number, user: {
        id: number;
    } | UserCompact, type: "best" | "firsts" | "recent", options?: {
        gamemode?: GameModes;
        include_fails?: Boolean;
        offset?: number;
    }): Promise<Score[] | APIError>;
    getUserKudosu(user: {
        id: number;
    } | UserCompact, limit?: number, offset?: number): Promise<KudosuHistory[] | APIError>;
    getBeatmap(beatmap: {
        id: number;
    } | BeatmapCompact): Promise<Beatmap | APIError>;
    getBeatmaps(ids?: number[]): Promise<Beatmap[] | APIError>;
    getBeatmapUserScore(beatmap: {
        id: number;
    } | BeatmapCompact, user: {
        id: number;
    } | UserCompact, gamemode?: GameModes): Promise<BeatmapUserScore | APIError>;
    getRoom(room: {
        id: number;
    } | Room): Promise<Room | APIError>;
    /**
     * REQUIRES A USER ASSOCIATED TO THE API OBJECT
     */
    getRooms(mode?: "owned" | "participated" | "ended"): Promise<Room[] | APIError>;
    /**
     * REQUIRES A USER ASSOCIATED TO THE API OBJECT
     */
    getRoomLeaderboard(room: {
        id: number;
    } | Room): Promise<Leader[] | APIError>;
    /**
     * REQUIRES A USER ASSOCIATED TO THE API OBJECT
     */
    getPlaylistItemScores(item: PlaylistItem): Promise<MultiplayerScore[] | APIError>;
}
type Scope = "chat.write" | "delegate" | "forum.write" | "friends.read" | "identify" | "public";
export declare function generateAuthorizationURL(client_id: number, redirect_uri: string, scopes: Scope[]): string;
